==> qmmp-1.0.7.tar.bz2: qmmp-1.0.7/src/plugins/Input/sid/translations/sid_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="69"/>
        <source>SID Plugin</source>
        <translation>Wtyczka SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="71"/>
        <source>SID Files</source>
        <translation>Pliki SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="125"/>
        <source>About SID Audio Plugin</source>
        <translation>O wtyczce SID Audio</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="126"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>Wtyczka SID Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="127"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>Ta wtyczka umożliwia odtwarzanie plików muzycznych z Commodore 64 poprzez bibliotekę libsidplayfp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="128"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>Ustawienia wtyczki SID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>Szybkie przepróbkowanie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>Próbkowanie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>Plik bazy HVSC:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>Metoda próbkowania:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>Domyślna długość utworu, sek:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>Ustaw długość utworu z bazy HVSC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>Emulacja:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/sid/translations/sid_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="59"/>
        <source>SID Plugin</source>
        <translation>Wtyczka SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="61"/>
        <source>SID Files</source>
        <translation>Pliki SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="115"/>
        <source>About SID Audio Plugin</source>
        <translation>O wtyczce SID Audio</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="116"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>Wtyczka SID Audio dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="117"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>Ta wtyczka umożliwia odtwarzanie plików muzycznych z Commodore 64 poprzez bibliotekę libsidplayfp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="118"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>Ustawienia wtyczki SID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>Szybkie przepróbkowanie</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>Próbkowanie:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>Plik bazy HVSC:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>Metoda próbkowania:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>Domyślna długość utworu, sek:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>Ustaw długość utworu z bazy HVSC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>Emulacja:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
